%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Developed by:			Torbjrn Wigren
%                       Division of Systems and Control
%                       Department of Information Technology
%                       Uppsala University
%                       P O Box 337
%                       SE-751 05 Uppsala
%                       SWEDEN
%
% Version:					1.0, nonexisting
%                       2.0, MATLAB 5
%                       3.0, Added FIR
%
% Date:		        		rev. 1.0, nonexisting
%                       rev. 2.0, March 28 2007
%                       rev. 3.0, April 12 2007
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%                       DESCRIPTION
%
% This M-file adds a setup file for initialization of algorithm VIII of
% Wigren 1990.
%
% Variables:         B_0 = initial value of the B-polynomial
%                    F_0 = initial value of the F-polynomial
%		               kpl = kplus in the notes
%		               kmi = kminus in the notes
%                    k0 = known slope
%                    grid = vector containing grid points
%                    thetafy0_0 = bias parameter in the mid interval
%		               thetanon_0 = starting value of nonlinear parameter vector
%                    lambda0 = rate of gain sequence (0.99 in L&S)
%                    lambda_0 = initial value of gain sequence (0.95 in L&S)
%                    P_0 = initial value of the P-matrix

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initial values of corresponding to the linear part of the model
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
B_0=[0 0 0.5];
F_0=[1 -1 0.25];
%F_0=[1]; % FIR Initialization value
nb=size(B_0,2)-1;
na=size(F_0,2)-1;
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initial values of corresponding to the non-linear part of the model
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
kmi=1;
kpl=1;
k0=1;
grid=[-1.2 -0.3 0.3 1.2];
extgrid=[grid;zeros(1,kmi+kpl+2)];
extgrid=extgrid(:)';
extgrid=extgrid(1:2*kmi+2*kpl+3);
for i=1:kmi+kpl+1
  extgrid(2*i)=0.5*(extgrid(2*i+1)+extgrid(2*i-1));
end;
thetafy0_0=1;
thetanon_0=k0*extgrid(1:2*kmi)';
thetanon_0=[thetanon_0;k0*extgrid(2*kmi+4:2*kmi+2*kpl+3)']+thetafy0_0;
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Joint initial values
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
lambda0=0.99;
lambda_0=0.95;
P_0=1*eye(na+nb+2*kpl+2*kmi+1);

